@@ -139,14 +139,27 @@ class ModelResultJsonMixin(object):
             value. (Default is ``pk``, i.e. the id field of the model)
         :type to_field_name: :py:obj:`str`
         """
-        if self.queryset is None and not 'queryset' in kwargs:
-            raise ValueError('queryset is required.')
-
         self.max_results = getattr(self, 'max_results', None)
         self.to_field_name = getattr(self, 'to_field_name', 'pk')
 
         super(ModelResultJsonMixin, self).__init__(*args, **kwargs)
 
+    def get_queryset(self):
+        """
+        Returns the queryset.
+        
+        The default implementation returns the ``self.queryset``, which is usually the
+        one set by sub-classes at class-level. However, if that is ``None``
+        then ``ValueError`` is thrown.
+        
+        :return: queryset
+        :rtype: :py:class:`django.db.models.query.QuerySet`
+        """
+        if self.queryset is None:
+            raise ValueError('queryset is required.')
+
+        return self.queryset
+
     def label_from_instance(self, obj):
         """
         Sub-classes should override this to generate custom label texts for values.
@@ -246,7 +259,7 @@ class ModelResultJsonMixin(object):
         if not hasattr(self, 'search_fields') or not self.search_fields:
             raise ValueError('search_fields is required.')
 
-        qs = copy.deepcopy(self.queryset)
+        qs = copy.deepcopy(self.get_queryset())
         params = self.prepare_qs_params(request, term, self.search_fields)
 
         if self.max_results:
@@ -328,8 +341,8 @@ class FilterableModelChoiceIterator(ModelChoiceIterator):
         """
         Applies additional filter on the queryset. This can be called multiple times.
 
-        :param kwargs: The ``**kwargs`` to pass to :py:meth:`django.db.models.query.QuerySet.filter`.
-        If this is not set then additional filter (if) applied before is removed.
+        :param filter_map: The ``**kwargs`` to pass to :py:meth:`django.db.models.query.QuerySet.filter`.
+            If this is not set then additional filter (if) applied before is removed.
         """
         if not hasattr(self, '_original_queryset'):
             import copy
